Module: Magic::CoreExt::Kernel

Defined in:
lib/magic/core_ext/kernel/utils.rb,
sig/magic/core_ext/kernel.rbs

Constant Summary collapse

MODULES =

Some classes copy Kernel methods on initialization instead of including Kernel itself. Thus, new methods should be defined explicitly for them.

Returns:

  • (Array[Module])
[ # classes/modules including Kernel methods
    ::Kernel,
    (Delegator if defined? Delegator),
].compact.freeze